@@ -4,7 +4,7 @@ import logging
 
 from base64 import b64encode
 from requests.exceptions import RequestException
-from urllib import urlencode
+from urllib.parse import urlencode
 
 logger = logging.getLogger('eloqua.client')
 
@@ -13,16 +13,14 @@ API_VERSION = '2.0'
 
 
 class EloquaException(Exception):
-    error_description = None
-    error = None
 
-    def __init__(self, exc={'error_description': None, 'erorr': None}):
-        self.error_description = exc['error_description']
-        self.error = exc['error']
+    def __init__(self, reason, text):
+        self.reason = reason
+        self.text = text
 
     def __str__(self):
-        return "Eloqua API Error {}: {}".format(
-            self.error, self.error_description)
+        return "Eloqua API Error: {}, reason: {}".format(
+            self.text, self.reason)
 
 
 class EloquaBulkClient(object):
@@ -180,7 +178,7 @@ class EloquaBulkClient(object):
 
         url = '{base_url}{sync_uri}/data?limit={limit}&offset={offset}'.format(
             base_url=self.base_url,
-            sync_uri=self.sync_uri,
+            sync_uri=sync_uri,
             limit=batch_size,
             offset=offset)
 
@@ -210,10 +208,9 @@ class EloquaBulkClient(object):
 
         resp = requests.request(**kwargs)
 
-        logger.info(u'{method} response: {status} {text}'.format(
+        logger.info(u'{method} response: {status}'.format(
                     method=kwargs['method'],
-                    status=resp.status_code,
-                    text=resp.text))
+                    status=resp.status_code))
 
         return resp
 
@@ -229,7 +226,7 @@ class EloquaBulkClient(object):
             raise e
         else:
             if r.status_code >= 400:
-                raise EloquaException(r.json())
+                raise EloquaException(r.reason, r.text)
             if r.status_code == 204:
                 return None
             return r.json()
@@ -249,5 +246,5 @@ class EloquaBulkClient(object):
             raise e
         else:
             if r.status_code >= 400:
-                raise EloquaException(r.json())
+                raise EloquaException(r.reason, r.text)
             return r.json()
